@@ -31,7 +31,8 @@ struct _archive
 
 	gdouble		amount;
 	guint32		kacc;
-	gushort		paymode;
+	guchar		paymode;
+	guchar		grpflg;
 	gushort		flags;
 	guint32		kpay;
 	guint32		kcat;
@@ -40,7 +41,7 @@ struct _archive
 	//guint32		date;
 	//gushort		pos;
 	gushort     status;
-	gchar		*info;
+	gchar		*number;	//info < 5.8
 	guint32		*tags;
 	//guint32		kxfer;		//strong link xfer key
 	guint32		kxferacc;
@@ -48,6 +49,7 @@ struct _archive
 	
 	GPtrArray	*splits;
 
+	/* automation data */
 	guint32		nextdate;
 	gushort		daygap;
 	gushort		every;
@@ -57,16 +59,6 @@ struct _archive
 };
 
 
-/* list define archive (defarchive) */
-enum
-{
-	LST_DEFARC_DATAS,
-//	LST_DEFARC_OLDPOS,
-//	LST_DEFARC_AUTO,
-	NUM_LST_DEFARC
-};
-
-
 enum
 {
 	ARC_POSTMODE_DUEDATE,
@@ -129,17 +121,17 @@ Archive *da_archive_get(guint32 key);
 void da_archive_get_display_label(GString *tpltitle, Archive *item);
 void da_archive_consistency(Archive *item);
 
-Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboolean fromregister);
+Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboolean fromledger);
 
 GList *da_archive_glist_sorted(gint column);
 
 gboolean template_is_account_used(Archive *arc);
 
 void scheduled_nextdate_weekend_adjust(Archive *arc);
-guint32 scheduled_date_get_next_post(GDate *tmpdate, Archive *arc, guint32 nextdate);
+guint32 scheduled_date_get_next_post(GDate *date, Archive *arc, guint32 nextdate);
 gboolean scheduled_is_postable(Archive *arc);
 guint32 scheduled_get_postdate(Archive *arc, guint32 postdate);
-guint32 scheduled_get_latepost_count(Archive *arc, guint32 jrefdate);
+guint32 scheduled_get_latepost_count(GDate *date, Archive *arc, guint32 jrefdate);
 guint32 scheduled_date_advance(Archive *arc);
 
 void scheduled_date_get_show_minmax(gint select, guint32 *mindate, guint32 *maxdate);
