@@ -21,13 +21,17 @@
 #define __HUB_REPTIME_H__
 
 
+// /!\ prefs stored value
 enum {
 	HUB_TIM_VIEW_NONE,
 	HUB_TIM_VIEW_SPENDING,
 	HUB_TIM_VIEW_ACCBALANCE,
 	HUB_TIM_VIEW_ALLBALANCE,
 	//5.7.3
-	HUB_TIM_VIEW_GRPBALANCE
+	HUB_TIM_VIEW_GRPBALANCE,
+	//5.7.5
+	HUB_TIM_VIEW_REVENUE,
+	HUB_TIM_VIEW_SPEREV,
 };
 
 
