@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2023 Maxime DOYEN
+ *  Copyright (C) 1995-2024 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -136,7 +136,7 @@ GtkWidget *ui_acc_entry_popover_new(GtkWidget *label);
 
 /* = = = = = = = = = = */
 
-void ui_acc_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter);
+guint ui_acc_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter);
 
 void ui_acc_listview_quick_select(GtkTreeView *treeview, const gchar *uri);
 
