@@ -21,18 +21,6 @@
 #define __HB_ARCHIVE_GTK_H__
 
 
-enum {
-	LST_DEFARC_SORT_DATE = 1,
-	LST_DEFARC_SORT_INFO,
-	LST_DEFARC_SORT_MEMO,
-	LST_DEFARC_SORT_PAYEE,
-	LST_DEFARC_SORT_CATEGORY,
-	LST_DEFARC_SORT_CLR,
-	LST_DEFARC_SORT_AMOUNT,
-	LST_DEFARC_SORT_ACCOUNT
-};
-
-
 enum {
 	HID_ARC_MEMO,
 	HID_ARC_VALID,
